
-- For merging tables
function merge(t1, t2)
    assert(t1, "Table merge failed: No table1 provided !")
    assert(t2, "Table merge failed: No table2 provided !")
    for k, v in pairs(t2) do
        if (type(v) == "table") and (type(t1[k] or false) == "table") then
            merge(t1[k], t2[k])
        else
            t1[k] = v
        end
    end
    return t1
end

local function register_entry(entry)
    assert(entry, "Data extension failed: No entity provided !")
    if entry.based_on ~= nil then
        data:extend({
            merge(table.deepcopy(entry.based_on), entry)
        })
    else
        data:extend({
            entry,
        })
    end
end

function data_extend(entry_list)
    if entry_list.name then         -- kind of sketchy
        -- Provided just one entry
        register_entry(entry_list)
    else
        -- Provided list of entries
        for _, entry in pairs(entry_list) do
            register_entry(entry)
        end
    end
end

solar_accumulator_compression_level  = 4
boiler_engine_compression_level      = 2
miner_furnace_compression_level      = 2
refinery_chemplant_compression_level = 2

-- All modifiers (WARNING - mathematical formulas):
function get_modifiers_for_tier(tier)
    
    return
    {
        general_solar_accumulator_mod  = math.pow(solar_accumulator_compression_level,  tier - 1),
        general_miner_furnace_mod      = math.pow(miner_furnace_compression_level,      tier - 1),
        general_refinery_chemplant_mod = math.pow(refinery_chemplant_compression_level, tier - 1),
        general_boiler_engine_mod      = math.pow(boiler_engine_compression_level,      tier - 1),
        
        general_health_mod = tier,
        
        solar_accumulator_crafting_speed = 5 * tier + 5,
        
        miner_crafting_speed   = 6 * tier - 4,
        furnace_crafting_speed = 5 * tier,
        
        short_crafting_speed        = (tier + 2) / 6,       -- short crafting speed (0.5s)
        refinery_crafting_speed     = 10 * tier + 10,
        chemplant_crafting_speed    = 5 * tier + 5,
        storage_tank_crafting_speed = 2 * tier + 1,
        pump_crafting_speed         = 2 * tier,
        
        miner_animation_speed_mod = (2 * tier + 1) / 3,
        
        furnace_module_slots = tier <= 2 and 2 or 3,
        
        boiler_effectivity_mod = (tier + 2) / 3,
    }
    
end

require("prototypes.solar-accumulator")                                         -- All Solar Panels and Accumulators
require("prototypes.miner-furnace")                                             -- All Electric Mining Drills and Electric Furnaces
require("prototypes.refinery-chemplant")                                        -- All Refineries and Chemical Plants
require("prototypes.pipeworks")                                                 -- All pipes, pipes-to-ground, storage tanks etc.
require("prototypes.boiler-engine")                                             -- All Boilers and Steam Engines

require("prototypes.substation_mk2.substation-mk2")                             -- Substation MK2
require("prototypes.substation_mk2.replaceable-poles")                          -- Replacable poles

require("prototypes.ultra-fast-inserter")                                       -- Ultra fast inserter
require("prototypes.advanced-repair-pack")                                      -- Advanced Repair Pack

require("prototypes.technology.compact-solar-energy")                           -- Technologies
require("prototypes.technology.compact-steam-energy")
require("prototypes.technology.compact-material-processing")
require("prototypes.technology.compact-oil-processing")
require("prototypes.technology.ultra-fast-inserter")
require("prototypes.technology.advanced-repair-pack")
