
local function get_effects_for_level(level)
    
    local effects = {}
    
    table.insert(effects, { type = "unlock-recipe", recipe = "electric-furnace-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "mining-drill-mk" .. level + 1 })
    
    return effects
    
end

local function get_ingredients_for_level(level)
    
    local blue = 
    {
        {"science-pack-1", 1},
        {"science-pack-2", 1},
        {"science-pack-3", 1},
    }
    
    if level <= 2 then
        return blue
    else
        table.insert(blue, {"alien-science-pack", 1})
        return blue
    end
    
end

local function get_prequisites_for_level(level)
    
    local preqs = {}
    
    if level == 1 then
        preqs = { "advanced-material-processing-2", "advanced-electronics-2", "speed-module" }
    elseif level == 2 then
        preqs = { "speed-module-2", "effectivity-module-2" }
    elseif level == 3 then
        preqs = { "alien-technology", "speed-module-3" }
    end
    
    if level == 2 then
        table.insert(preqs, 1, "compact-material-processing" )
    elseif level >= 3 then
        table.insert(preqs, 1, "compact-material-processing-" .. level - 1 )
    end
    
    return preqs
    
end

local function make_compact_material_processing_tech_for_level(level)
    
    return
    {
        type = "technology",
        name = level == 1 and "compact-material-processing" or "compact-material-processing-" .. level,
        icon = "__Compact_Factory__/graphics/technology/compact-material-processing.png",
        icon_size = 128,
        effects = get_effects_for_level(level),
        prerequisites = get_prequisites_for_level(level),
        upgrade = true,
        unit =
        {
            count = (100 * math.pow(level, 2)) + 100,
            ingredients = get_ingredients_for_level(level),
            time = 15 * (level + 1),
        },
        order = "c-c-b",
    }
    
end

compact_material_processing_start_tech = 1
compact_material_processing_stop_tech  = 3

local CompactMaterialProcessingTech = {}

for level = compact_material_processing_start_tech, compact_material_processing_stop_tech do
    table.insert(CompactMaterialProcessingTech, make_compact_material_processing_tech_for_level(level))
end

data_extend(CompactMaterialProcessingTech)
