
local function get_effects_for_level(level)
    
    local effects = {}
    
    table.insert(effects, { type = "unlock-recipe", recipe = "refinery-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "chemical-plant-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "pipe-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "pipe-to-ground-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "storage-tank-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "pump-mk" .. level + 1 })
    
    return effects
    
end

local function get_ingredients_for_level(level)
    
    local blue = 
    {
        {"science-pack-1", 1},
        {"science-pack-2", 1},
        {"science-pack-3", 1},
    }
    
    if level <= 2 then
        return blue
    else
        table.insert(blue, {"alien-science-pack", 1})
        return blue
    end
    
end

local function get_prequisites_for_level(level)
    
    local preqs = {}
    
    if level == 1 then
        preqs = { "advanced-oil-processing", "fluid-handling", "speed-module" }
    elseif level == 2 then
        preqs = { "speed-module-2", "effectivity-module-2" }
    elseif level == 3 then
        preqs = { "alien-technology", "speed-module-3" }
    end
    
    if level == 2 then
        table.insert(preqs, 1, "compact-oil-processing" )
    elseif level >= 3 then
        table.insert(preqs, 1, "compact-oil-processing-" .. level - 1 )
    end
    
    return preqs
    
end

local function make_compact_oil_processing_tech_for_level(level)
    
    return
    {
        type = "technology",
        name = level == 1 and "compact-oil-processing" or "compact-oil-processing-" .. level,
        icon = "__Compact_Factory__/graphics/technology/compact-oil-processing.png",
        icon_size = 128,
        effects = get_effects_for_level(level),
        prerequisites = get_prequisites_for_level(level),
        upgrade = true,
        unit =
        {
            count = (100 * math.pow(level, 2)) + 100,
            ingredients = get_ingredients_for_level(level),
            time = 15 * (level + 1),
        },
        order = "d-b-a",
    }
    
end

compact_oil_processing_start_tech = 1
compact_oil_processing_stop_tech  = 3

local CompactEnergyTech = {}

for level = compact_oil_processing_start_tech, compact_oil_processing_stop_tech do
    table.insert(CompactEnergyTech, make_compact_oil_processing_tech_for_level(level))
end

data_extend(CompactEnergyTech)
