
local function get_effects_for_level(level)
    
    local effects = {}
    
    table.insert(effects, { type = "unlock-recipe", recipe = "solar-panel-mk" .. level + 1 })
    table.insert(effects, { type = "unlock-recipe", recipe = "accumulator-mk" .. level + 1 })
    if level == 1 then
        table.insert(effects, { type = "unlock-recipe", recipe = "substation-mk2" })
    end
    
    return effects
    
end

local function get_ingredients_for_level(level)
    
    local blue = 
    {
        {"science-pack-1", 1},
        {"science-pack-2", 1},
        {"science-pack-3", 1},
    }
    
    if level <= 2 then
        return blue
    else
        table.insert(blue, {"alien-science-pack", 1})
        return blue
    end
    
end

local function get_prequisites_for_level(level)
    
    local preqs = {}
    
    if level == 1 then
        preqs = { "solar-energy", "electric-energy-accumulators-1", "electric-energy-distribution-2" }
    elseif level == 4 then
        preqs = { "fusion-reactor-equipment", "battery-mk2-equipment" }
    end
    
    if level == 2 then
        table.insert(preqs, 1, "compact-solar-energy" )
    elseif level >= 3 then
        table.insert(preqs, 1, "compact-solar-energy-" .. level - 1 )
    end
    
    return preqs
    
end

local function make_compact_solar_tech_for_level(level)
    
    return
    {
        type = "technology",
        name = level == 1 and "compact-solar-energy" or "compact-solar-energy-" .. level,
        icon = "__Compact_Factory__/graphics/technology/compact-solar-energy-mk" .. level + 1 .. "-tech.png",
        icon_size = 128,
        effects = get_effects_for_level(level),
        prerequisites = get_prequisites_for_level(level),
        upgrade = true,
        unit =
        {
            count = (100 * math.pow(level, 2)) + 100,
            ingredients = get_ingredients_for_level(level),
            time = 15 * (level + 1),
        },
        order = "a-h-d",
    }
    
end

compact_solar_energy_start_tech = 1
compact_solar_energy_stop_tech  = 4

local CompactEnergyTech = {}

for level = compact_solar_energy_start_tech, compact_solar_energy_stop_tech do
    table.insert(CompactEnergyTech, make_compact_solar_tech_for_level(level))
end

data_extend(CompactEnergyTech)
